]> git.sesse.net Git - cubemap/blobdiff - client.h
Add support for forced prebuffering.
[cubemap] / client.h
index cd909e39e0032cc4fa23e317e389fdc1bb96f2da..d23b860767e16ecc372ab5726c6df8f2044ae7e3 100644 (file)
--- a/client.h
+++ b/client.h
@@ -14,7 +14,6 @@ struct Stream;
 struct ClientStats {
        std::string url;
        int sock;
-       int fwmark;
        std::string remote_addr;
        time_t connect_time;
        size_t bytes_sent;
@@ -34,14 +33,11 @@ struct Client {
        // The file descriptor associated with this socket.
        int sock;
 
-       // The fwmark associated with this socket (or 0).
-       int fwmark;
-
        // Some information only used for logging.
        std::string remote_addr;
        time_t connect_time;
 
-       enum State { READING_REQUEST, SENDING_HEADER, SENDING_DATA, SENDING_ERROR };
+       enum State { READING_REQUEST, SENDING_HEADER, SENDING_DATA, SENDING_ERROR, WAITING_FOR_KEYFRAME, PREBUFFERING };
        State state;
 
        // The HTTP request, as sent by the client. If we are in READING_REQUEST,
@@ -64,9 +60,10 @@ struct Client {
 
        // Number of bytes we are into the stream (ie., the end of last send).
        // -1 means we want to send from the end of the backlog (the normal case),
+       // although only at a keyframe.
        // -2 means we want to send from the _beginning_ of the backlog.
// Once we go into SENDING_DATA, these negative values will be translated
// to real numbers.
        size_t stream_pos;
 
        // Number of bytes we've sent of data. Only relevant for SENDING_DATA.
@@ -64,9 +60,10 @@ struct Client {
        // -2 means we want to send from the _beginning_ of the backlog.
-       // Once we go into SENDING_DATA, these negative values will be translated
-       // to real numbers.
+       // Once we go into WAITING_FOR_KEYFRAME, PREBUFFERING or SENDING_DATA,
+       // these negative values will be translated to real numbers.
        size_t stream_pos;
 